# Changelog

## [0.3.1](https://github.com/firefly-cpp/AST-Monitor/tree/0.3.1) (2022-09-15)

[Full Changelog](https://github.com/firefly-cpp/AST-Monitor/compare/0.3.0...0.3.1)

**Closed issues:**

- Path error [\#29](https://github.com/firefly-cpp/AST-Monitor/issues/29)
- Add a short outline/description of each figure in README [\#25](https://github.com/firefly-cpp/AST-Monitor/issues/25)

**Merged pull requests:**

- Small bugifx [\#30](https://github.com/firefly-cpp/AST-Monitor/pull/30) ([luckyLukac](https://github.com/luckyLukac))

## [0.3.0](https://github.com/firefly-cpp/AST-Monitor/tree/0.3.0) (2022-09-13)

[Full Changelog](https://github.com/firefly-cpp/AST-Monitor/compare/0.2.1...0.3.0)

**Closed issues:**

- Show various TRIMP values on the dashboard [\#21](https://github.com/firefly-cpp/AST-Monitor/issues/21)
- Add reference/minor documentation for ast-tdl [\#17](https://github.com/firefly-cpp/AST-Monitor/issues/17)

**Merged pull requests:**

- Complete revamp of the AST-Monitor application [\#28](https://github.com/firefly-cpp/AST-Monitor/pull/28) ([luckyLukac](https://github.com/luckyLukac))
- Update lock file [\#27](https://github.com/firefly-cpp/AST-Monitor/pull/27) ([firefly-cpp](https://github.com/firefly-cpp))
- Add instructions for install from AUR [\#26](https://github.com/firefly-cpp/AST-Monitor/pull/26) ([carlosal1015](https://github.com/carlosal1015))

## [0.2.1](https://github.com/firefly-cpp/AST-Monitor/tree/0.2.1) (2022-07-22)

[Full Changelog](https://github.com/firefly-cpp/AST-Monitor/compare/0.2.0...0.2.1)

**Merged pull requests:**

- Slight digital twin algorithm and GUI improvements [\#24](https://github.com/firefly-cpp/AST-Monitor/pull/24) ([luckyLukac](https://github.com/luckyLukac))
- Digital twin improvements [\#23](https://github.com/firefly-cpp/AST-Monitor/pull/23) ([luckyLukac](https://github.com/luckyLukac))

## [0.2.0](https://github.com/firefly-cpp/AST-Monitor/tree/0.2.0) (2022-07-12)

[Full Changelog](https://github.com/firefly-cpp/AST-Monitor/compare/0.1.5...0.2.0)

**Closed issues:**

- Generate tcx/gpx file from sensor data [\#5](https://github.com/firefly-cpp/AST-Monitor/issues/5)

**Merged pull requests:**

- Digital twin implementation [\#22](https://github.com/firefly-cpp/AST-Monitor/pull/22) ([luckyLukac](https://github.com/luckyLukac))
- Interval data depiction [\#19](https://github.com/firefly-cpp/AST-Monitor/pull/19) ([luckyLukac](https://github.com/luckyLukac))

## [0.1.5](https://github.com/firefly-cpp/AST-Monitor/tree/0.1.5) (2022-06-24)

[Full Changelog](https://github.com/firefly-cpp/AST-Monitor/compare/0.1.4...0.1.5)

**Merged pull requests:**

- Minor Flake8 changes [\#18](https://github.com/firefly-cpp/AST-Monitor/pull/18) ([luckyLukac](https://github.com/luckyLukac))
- Training loading and unit tests fix [\#16](https://github.com/firefly-cpp/AST-Monitor/pull/16) ([luckyLukac](https://github.com/luckyLukac))

## [0.1.4](https://github.com/firefly-cpp/AST-Monitor/tree/0.1.4) (2022-06-07)

[Full Changelog](https://github.com/firefly-cpp/AST-Monitor/compare/0.1.3...0.1.4)

**Closed issues:**

- Screenshot of GUI [\#11](https://github.com/firefly-cpp/AST-Monitor/issues/11)

**Merged pull requests:**

- Update README.md [\#14](https://github.com/firefly-cpp/AST-Monitor/pull/14) ([luckyLukac](https://github.com/luckyLukac))
- Map addition [\#13](https://github.com/firefly-cpp/AST-Monitor/pull/13) ([luckyLukac](https://github.com/luckyLukac))
- GUI and code improvements [\#12](https://github.com/firefly-cpp/AST-Monitor/pull/12) ([luckyLukac](https://github.com/luckyLukac))

## [0.1.3](https://github.com/firefly-cpp/AST-Monitor/tree/0.1.3) (2022-05-03)

[Full Changelog](https://github.com/firefly-cpp/AST-Monitor/compare/0.1.2...0.1.3)

**Merged pull requests:**

- GUI enhancements [\#10](https://github.com/firefly-cpp/AST-Monitor/pull/10) ([luckyLukac](https://github.com/luckyLukac))
- Redesigned GUI [\#9](https://github.com/firefly-cpp/AST-Monitor/pull/9) ([luckyLukac](https://github.com/luckyLukac))
- Update README.md [\#6](https://github.com/firefly-cpp/AST-Monitor/pull/6) ([alenrajsp](https://github.com/alenrajsp))

## [0.1.2](https://github.com/firefly-cpp/AST-Monitor/tree/0.1.2) (2022-03-10)

[Full Changelog](https://github.com/firefly-cpp/AST-Monitor/compare/0.1.1...0.1.2)

**Closed issues:**

- 'ant' module cannot be installed using PIP [\#1](https://github.com/firefly-cpp/AST-Monitor/issues/1)

**Merged pull requests:**

- Small changes in GUI [\#4](https://github.com/firefly-cpp/AST-Monitor/pull/4) ([luckyLukac](https://github.com/luckyLukac))
- Code refactored to comply with Flake standards [\#3](https://github.com/firefly-cpp/AST-Monitor/pull/3) ([luckyLukac](https://github.com/luckyLukac))
- Small bugfix at pyqt-feedback-flow usage [\#2](https://github.com/firefly-cpp/AST-Monitor/pull/2) ([luckyLukac](https://github.com/luckyLukac))

## [0.1.1](https://github.com/firefly-cpp/AST-Monitor/tree/0.1.1) (2022-01-25)

[Full Changelog](https://github.com/firefly-cpp/AST-Monitor/compare/c3527a1296385a84a0b0be4df0e1609527cbac67...0.1.1)



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
